@@ -6,22 +6,12 @@ use warnings FATAL => 'all';
 use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
-BEGIN {
-	use Term::ReadLine;
-	$ENV{TERM} = 'dumb' if !exists $ENV{TERM};
-
-	eval { my $term = Term::ReadLine->new('none') };
-	if ($EVAL_ERROR) {
-		local $ENV{PERL_RL} = ' ornaments=0';
-	}
+use Term::ReadLine;
+if ( $OSNAME eq 'MSWin32' ) {
+	$ENV{TERM} = 'dumb';
+	local $ENV{PERL_RL} = ' ornaments=0';
 }
 
-# Patch for Debug::Client ticket #831 (MJGARDNER)
-# Turn off ReadLine ornaments
-##local $ENV{PERL_RL} = ' ornaments=0';
-##$ENV{TERM} = 'dumb' if ! exists $ENV{TERM};
-
-
 if ( $OSNAME eq 'MSWin32' ) {
 	require Win32::Process;
 	require Win32;
@@ -45,7 +35,7 @@ sub start_script {
 	my $path = $dir;
 	my $pid;
 	if ( $OSNAME eq 'MSWin32' ) {
-		$pid  = 'fudge'; # as we don't get one from win32
+		$pid  = 'fudge';                      # as we don't get one from win32
 		$path = Win32::GetLongPathName($path);
 		local $ENV{PERLDB_OPTS} = "RemotePort=$host:$port";
 
